# TODO

1. Support more complex spin & color contractions:
   1. color mix operator
   2. baryon operator
2. More transformations:
   1. More general common subexpression elimination (works for more general spin & color contractions)
   2. Common subexpression elimination for summation over coordinates.
   3. Complex conjugate and $\gamma_5$ hermiticity.
3. Efficient evaluation
   1. Parallel evaluations.
   2. Generic C++ code to compute the contraction.
   3. Perhaps dynamical load the code to Python.
